#include <QApplication>
#include <QUiLoader>
#include <QFileDialog>
#include <QFile>
#include <QComboBox>
#include <QFileInfo>
#include "qwwuiviewer.h"


QwwUiViewer::QwwUiViewer(QWidget *parent) : QMainWindow(parent){
    ui.setupUi(this);
    setAttribute(Qt::WA_DeleteOnClose, true);
    usedStyle = 0;
    slave = 0;
    styleBox = new QComboBox(this);
    ui.toolBar->addWidget(styleBox);
    styleBox->addItems(_styles.keys());
    connect(styleBox, SIGNAL(currentIndexChanged(const QString &)),
                      SLOT(changeStyle(const QString &)));
    connect(ui.actionExit, SIGNAL(triggered()), SLOT(close()));                
    styleBox->setCurrentIndex(styleBox->findText(qApp->style()->objectName(), Qt::MatchContains));
}

QwwUiViewer::~QwwUiViewer(){
  if(slave) slave->deleteLater();
  if(usedStyle) usedStyle->deleteLater();
}

void QwwUiViewer::applyStyle(QStyle *s){
    if(slave){
      slave->setStyle(s);
      foreach(QWidget *o, slave->findChildren<QWidget*>()) {
        o->setStyle(s);
      }
                     
    }
  }
  
void QwwUiViewer::on_actionOpenFile_triggered(){
    delete slave;
    slave = 0;
    QString path = QFileDialog::getOpenFileName(this, tr("Choose an UI file"), 
                    _lastDir, "*.ui");
    if(path.isEmpty())
      return;
    loadUi(path);
  }
  
void QwwUiViewer::changeStyle(const QString &text){
    QStyle *s = _styles.create(text);
    if(!s) return;
    applyStyle(s);
    delete usedStyle;
    usedStyle = s;
}

void QwwUiViewer::loadUi(const QString &path){
    QFileInfo finfo(path);
    _lastDir=finfo.absolutePath();
    QUiLoader loader;
    QFile file(path);
    if(!file.open(QFile::ReadOnly)) return;
    slave = loader.load(&file, 0);
    file.close();
    if(!slave) return;
    if(!slave->inherits("QDialog") && !slave->inherits("QMainWindow")){
      setCentralWidget(slave);
    }
//    slave->setAttribute(Qt::WA_DeleteOnClose, true);
    applyStyle(usedStyle);
    slave->show();
}
